@@ -1,3 +1,4 @@
+globalVariables(".")
 #' Create a thematic map
 #'
 #' It creates a thematic map based on co-word network analysis and clustering.
@@ -24,6 +25,7 @@
 #' @param repel is logical. If it is TRUE ggplot uses geom_label_repel instead of geom_label.
 #' @param remove.terms is a character vector. It contains a list of additional terms to delete from the documents before term extraction. The default is \code{remove.terms = NULL}.
 #' @param synonyms is a character vector. Each element contains a list of synonyms, separated by ";",  that will be merged into a single term (the first word contained in the vector element). The default is \code{synonyms = NULL}.
+#' @param cluster is a character. It indicates the type of cluster to perform among ("optimal", "louvain","leiden", "infomap","edge_betweenness","walktrap", "spinglass", "leading_eigen", "fast_greedy").
 #' @return a list containing:
 #' \tabular{lll}{
 #' \code{map}\tab   \tab The thematic map as ggplot2 object\cr
@@ -45,7 +47,7 @@
 #'
 #' @export
 
-thematicMap <- function(M, field="ID", n=250, minfreq=5, ngrams=1, stemming=FALSE, size=0.5, n.labels=1, repel=TRUE, remove.terms=NULL, synonyms=NULL){
+thematicMap <- function(M, field="ID", n=250, minfreq=5, ngrams=1, stemming=FALSE, size=0.5, n.labels=1, repel=TRUE, remove.terms=NULL, synonyms=NULL, cluster="leading_eigen"){
   
   minfreq <- max(2,floor(minfreq*nrow(M)/1000))
   
@@ -71,12 +73,9 @@ thematicMap <- function(M, field="ID", n=250, minfreq=5, ngrams=1, stemming=FALS
            
          })
   
-  #S <- normalizeSimilarity(NetMatrix, type = "association")
-  #S=NetMatrix
-  #t = tempfile();pdf(file=t) #### trick to hide igraph plot
   if (nrow(NetMatrix)>0){
     Net <- networkPlot(NetMatrix, normalize="association", Title = "Keyword co-occurrences",type="auto",
-                     labelsize = 2, halo = F,cluster="louvain",remove.isolates=TRUE,
+                     labelsize = 2, halo = F,cluster=cluster,remove.isolates=TRUE,community.repulsion = 0.1,
                      remove.multiple=FALSE, noloops=TRUE, weighted=TRUE,label.cex=T,edgesize=5, 
                      size=1,edges.min = 1, label.n=n, verbose = FALSE)
   }else{
@@ -114,74 +113,64 @@ thematicMap <- function(M, field="ID", n=250, minfreq=5, ngrams=1, stemming=FALS
 ### centrality and density
   label_cluster=unique(group)
   word_cluster=word[group]
-  centrality=c()
-  density=c()
-  labels=list()
+
+  centr <- networkStat(Net$graph,stat="all", type="closeness")$vertex
+  df_lab <- data.frame(sC=sC,words=word,groups=group,color=color,cluster_label="NA",stringsAsFactors = FALSE)
+   
+  ## new code using tidyvverse
+  df_lab <- df_lab %>% 
+    dplyr::filter(.data$sC>=minfreq) %>% 
+    group_by(.data$groups) %>% 
+    mutate(freq = sum(.data$sC),
+           cluster_label = .data$words[which.max(.data$sC)]) 
   
-  df_lab=data.frame(sC=sC,words=word,groups=group,color=color,cluster_label="NA",stringsAsFactors = FALSE)
+  sEij <- triu(sEij)
+  df_lab_top <- df_lab %>% select(.data$words,.data$groups)
+  
+  sEij_df <- as.matrix(sEij) %>% 
+    data.frame() %>% 
+    rename_with(~ row.names(sEij), .cols = colnames(.)) %>% 
+    mutate(words1 = row.names(sEij)) %>% 
+    pivot_longer(cols=!.data$words1, names_to = "words2", values_to = "eij") %>% 
+    dplyr::filter(.data$eij>0) %>% 
+    left_join(df_lab_top, by=c("words1" = "words")) %>% 
+    left_join(df_lab_top, by=c("words2" = "words")) %>% 
+    rename(groups =.data$groups.x,
+           groups2 =.data$groups.y)
+    
+  df_lab_top <- df_lab %>% select(.data$groups, .data$cluster_label,.data$color, .data$freq) %>% slice_head(n=1)
+  
+  df <- sEij_df %>% 
+    dplyr::filter(.data$words1 %in% unique(df_lab$words) & .data$words2 %in% unique(df_lab$words)) %>% 
+    group_by(.data$groups) %>% 
+    mutate(ext = as.numeric(.data$groups!=.data$groups2)) %>% 
+    summarize(n=length(unique(.data$words1)),
+              centrality = sum(.data$eij*.data$ext),
+              density = sum((.data$eij*(1-.data$ext))/.data$n)*100
+              ) %>% 
+    mutate(rcentrality=rank(.data$centrality),
+      rdensity=rank(.data$density)
+    ) %>% 
+    left_join(., df_lab_top, by = "groups") %>% 
+    rename(label = .data$cluster_label)
   
-  color=c()
-  for (i in label_cluster){
-    ind=which(group==i)
-    w=df_lab$words[ind]
-    wi=which.max(df_lab$sC[ind])
-    df_lab$cluster_label[ind]=paste(w[wi[1:min(c(length(wi),3))]],collapse=";",sep="")
-    centrality=c(centrality,sum(sEij[ind,-ind]))
-    density=c(density,sum(sEij[ind,ind])/length(ind)*100)
-    df_lab_g=df_lab[ind,]
-    df_lab_g=df_lab_g[order(df_lab_g$sC,decreasing = T),]
-    #if (dim(df_lab_g)[1]>2){k=3}else{k=1}
-    k=1
-    labels[[length(labels)+1]]=paste(df_lab_g$words[1:k],collapse = ";")
-    color=c(color,df_lab$color[ind[1]])
-  }
-  #df_lab$cluster_label=gsub(";NA;",";",df_lab$cluster_label)
   
-  centrality=centrality
-  df=data.frame(centrality=centrality,density=density,rcentrality=rank(centrality),rdensity=rank(density),label=label_cluster,color=color)
- 
   meandens=mean(df$rdensity)
   meancentr=mean(df$rcentrality)
   rangex=max(c(meancentr-min(df$rcentrality),max(df$rcentrality)-meancentr))
   rangey=max(c(meandens-min(df$rdensity),max(df$rdensity)-meandens))
   
-  df$name=unlist(labels)
-  df=df[order(df$label),]
-  df_lab <- df_lab[df_lab$sC>=minfreq,]
-  df=df[(df$name %in% intersect(df$name,df_lab$cluster_label)),]
-  
-  row.names(df)=df$label
-  
-  A <- group_by(df_lab, .data$groups) %>% summarise(freq = sum(.data$sC)) %>% as.data.frame
-  
-  df$freq=A[,2]
-  
-  W <- df_lab %>% group_by(.data$groups) %>% #dplyr::filter(.data$sC>1) %>% 
+  df <- df_lab %>% group_by(.data$groups) %>% #dplyr::filter(.data$sC>1) %>% 
     arrange(-.data$sC, .by_group = TRUE) %>% 
-    dplyr::top_n(10, .data$sC) %>%
-    summarise(wordlist = paste(.data$words,.data$sC,collapse="\n")) %>% as.data.frame()
-  
-  df$words=W[,2]
-  
-  ### number of labels for each cluster
-  labels=gsub("\\d", "",df$words)
-  
-  ### cut ties over 10 words
-  df$words <- unlist(lapply(df$words, function(l){
-    l <- unlist(strsplit(l,"\\\n"))
-    l <- l[1:(min(length(l),10))]
-    l <- paste0(l,collapse="\n")
-  }))
-  
-  L=unlist(lapply(labels, function(l){
-    l=strsplit(l," \\\n")
-    l=paste(l[[1]][1:min(n.labels,lengths(l))], collapse="\n")
-  }))
-  df$name_full=L
-  ###
-  
-  xlimits=c(meancentr-rangex-0.5,meancentr+rangex+0.5)
-  ylimits=c(meandens-rangey-0.5,meandens+rangey+0.5)
+    dplyr::slice_max(n=10, .data$sC, with_ties=FALSE) %>%
+    summarise(wordlist = paste(.data$words,.data$sC,collapse="\n"),
+              name_full = paste(.data$words[1:min(n.labels,n())], collapse="\n")) %>% 
+    right_join(., df, by = "groups") %>% 
+    rename(name = .data$label,
+      words = .data$wordlist)
+
+  xlimits=c(meancentr-(rangex*1.2),meancentr+rangex*1.2)
+  ylimits=c(meandens-(rangey*1.2),meandens+rangey*1.2)
   
 
   annotations <- data.frame(
@@ -194,7 +183,7 @@ thematicMap <- function(M, field="ID", n=250, minfreq=5, ngrams=1, stemming=FALS
   data("logo",envir=environment())
   logo <- grid::rasterGrob(logo,interpolate = TRUE)
   
-  x <- c(max(df$rcentrality)-0.02-diff(range(df$rcentrality))*0.125, max(df$rcentrality)-0.02)+0.5
+  x <- c(max(df$rcentrality)-0.02-diff(range(df$rcentrality))*0.125, max(df$rcentrality)-0.02)+0.6
   y <- c(min(df$rdensity),min(df$rdensity)+diff(range(df$rdensity))*0.125)
 
   g=ggplot(df, aes(x=.data$rcentrality, y=.data$rdensity, text=c(.data$words))) +
@@ -216,31 +205,94 @@ thematicMap <- function(M, field="ID", n=250, minfreq=5, ngrams=1, stemming=FALS
       annotate("text",x=annotations$xpos,y= annotations$ypos,hjust=annotations$hjustvar,
                                          vjust=annotations$vjustvar,label=annotations$words, color=adjustcolor("gray20", alpha.f=0.5),size=3*(1+size))+
       theme(axis.text.x=element_blank(),
-        axis.ticks.x=element_blank(),
-        axis.text.y=element_blank(),
-        axis.ticks.y=element_blank()
-        ) + annotation_custom(logo, xmin = x[1], xmax = x[2], ymin = y[1], ymax = y[2]) 
-
-  names(df_lab)=c("Occurrences", "Words", "Cluster", "Color","Cluster_Label")
-  words=df_lab[order(df_lab$Cluster),]
-  words=words[!is.na(words$Color),]
-  words$Cluster=as.numeric(factor(words$Cluster))
-  row.names(df)=NULL
-
-  ### Adding column Topics
-  M$TOPIC=""
+            panel.background = element_rect(fill = '#FFFFFF'),
+            axis.line.x = element_line(color="black",size=0.5),
+            axis.line.y = element_line(color="black",size=0.5),
+            axis.ticks.x=element_blank(),
+            axis.text.y=element_blank(),
+            axis.ticks.y=element_blank()
+      ) + annotation_custom(logo, xmin = x[1], xmax = x[2], ymin = y[1], ymax = y[2]) 
+    
+  names(df_lab)=c("Occurrences", "Words", "Cluster", "Color","Cluster_Label", "Cluster_Frequency")
   
-  #View(res$words)
-  if (field %in% c("ID", "DE")) {
-    ID = paste(TERMS, ";", sep = "")
-    for (i in 1:nrow(words)) {
-      w = paste(words$Words[i], ";", sep = "")
-      TOPIC = paste(words$Cluster_Label[i], ";", sep = "")
-      ind = which(regexpr(w, ID) > -1)
-      M$TOPIC[ind] = paste(M$TOPIC[ind], TOPIC, sep = "")
-    }
-  } else {M$TOPIC="NA"}
+  df_lab <- df_lab %>% 
+    arrange(.data$Cluster) %>% 
+    dplyr::filter(!is.na(.data$Color)) %>% 
+    data.frame() %>% 
+    mutate(Cluster = as.numeric(factor(.data$Cluster)))
+
+  documentToClusters <- clusterAssignment(M, words=df_lab, field, remove.terms, synonyms)
   
-  results=list(map=g, clusters=df, words=words,nclust=dim(df)[1], net=Net, TOPIC=M$TOPIC)
+  
+  results=list(map=g, clusters=df, words=df_lab,nclust=dim(df)[1], net=Net, documentToClusters=documentToClusters)
 return(results)
 }
+
+# Probability calculation fro cluster assignment
+clusterAssignment <- function(M, words, field, remove.terms, synonyms){
+
+  #### integrate stopwords and synonyms in M original field  
+  if (field %in% c("AB","TI")) field <- paste0(field,"_TM")
+  Fi<-strsplit(M[,field],";")
+  nf <- lengths(Fi)
+  allField <- data.frame(terms=trim.leading(unlist(Fi)), SR=rep(M$SR,nf))
+  # remove terms
+  if (!is.null(remove.terms)){
+    allField <- anti_join(allField,data.frame(terms=trimws(toupper(remove.terms))), by="terms")
+  }
+    # Merge synonyms in the vector synonyms
+  if (!is.null(synonyms)){
+    s <- strsplit(toupper(synonyms),";")
+    snew <- unlist(lapply(s, function(l) l[1]))
+    sold <- lapply(s, function(l) trim.leading(l[-1]))
+    syn <- data.frame(new=rep(snew, lengths(sold)), terms=unlist(sold))
+    allField <- allField %>% left_join(syn, by="terms")
+    ind <- which(!is.na(allField$new))
+    allField$terms[ind] <- allField$new[ind]
+    allField <- allField[c("SR", "terms")]
+
+  }
+### stop integration in M  
+  
+  words <- words %>% 
+    mutate(p_w = 1/.data$Occurrences) %>% 
+    group_by(.data$Cluster) %>% 
+    mutate(p_c = 1/length(.data$Cluster))
+
+  TERMS <- allField %>% 
+    mutate(terms = .data$terms %>% tolower()) %>% 
+    left_join(words, by = c("terms" = "Words"))
+  
+  TERMS <- TERMS %>% 
+    group_by(.data$SR, .data$Cluster_Label) %>% 
+    summarize(weigth = sum(.data$p_w, na.rm = T)) %>% 
+    mutate(p = .data$weigth/sum(.data$weigth, na.rm=T)) %>% 
+    drop_na(.data$Cluster_Label) %>% 
+    ungroup()
+  
+  TERMS <- TERMS %>% 
+    select(-.data$weigth) %>% 
+    group_by(.data$SR)
+  
+  TERMS_Max <- TERMS %>% 
+    group_by(.data$SR) %>% 
+    slice_max(order_by = .data$p, n=1) %>% 
+    summarize(Assigned_cluster = paste(.data$Cluster_Label, collapse = ";"))
+  
+  TERMS <- TERMS %>% 
+    pivot_wider(names_from = .data$Cluster_Label, values_from = .data$p) %>% 
+    left_join(TERMS_Max, by = "SR")
+
+  
+  
+  if (!("DI" %in% names(M))) M$DI <- NA
+  
+  TERMS <- M %>% 
+    select(.data$DI, .data$AU, .data$TI, .data$SO, .data$PY,.data$TC, .data$SR) %>% 
+    left_join(TERMS, by = "SR") %>% 
+    mutate_if(is.numeric, ~replace_na(., 0)) %>% 
+    group_by(.data$Assigned_cluster) %>% 
+    arrange(desc(.data$TC), .by_group = TRUE)
+  
+  return(TERMS)
+}
